@@ -32,11 +32,13 @@
 
 static GSList *event_time_list = NULL;
 
-gboolean 
-timer_handler(gpointer data){
+gboolean timer_handler(gpointer data){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     time_t current_time;
+#ifdef PC_EMULATOR
+    char   *temp_string;
+#endif
 
     if(not_event == TRUE || !event_time_list)
 	return TRUE;
@@ -44,6 +46,12 @@ timer_handler(gpointer data){
     list_time_event_temp = event_time_list;  
     /* get current time */  
     current_time = time(NULL);
+#ifdef PC_EMULATOR    
+    temp_string = ctime(&current_time);
+    fprintf(stderr,"\nCurrent Time: %s\n",  temp_string);
+//    g_free(temp_string);
+    print_list();
+#endif	
     while(list_time_event_temp != NULL){
 	evt = list_time_event_temp->data;
 	if(evt->time <= current_time){
@@ -51,24 +59,29 @@ timer_handler(gpointer data){
 		case DAYTIMEEVENT :
      		    weather_frame_update(FALSE);   
 		break;
+		default:
 		case AUTOUPDATE:
-		    /* Reinitialise autoupdate event */ 
 		    /* delete periodic update */
-                    event_time_list=g_slist_remove(event_time_list,event_time_list->data);
+		    g_free(evt);
+                    event_time_list = g_slist_remove(event_time_list, event_time_list->data);
+		#ifdef PC_EMULATOR
 		    fprintf(stderr,"UPDATE by event\n");
+		#endif
 		    app->show_update_window = FALSE;
 		    update_weather();
                     /* add periodic update */
-                    add_periodic_event();
+                    add_periodic_event(current_time);
+		    
     		break;		    
 	    }
 	    break;
 	}             
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
-return TRUE;    
+    return TRUE;    
 }
 
+#ifdef PC_EMULATOR
 /*For debug */
 void print_list(void){
     static GSList *list_time_event_temp = NULL;
@@ -76,25 +89,26 @@ void print_list(void){
 
     if(!event_time_list)
 	return;
-    list_time_event_temp = event_time_list;  
-    while(list_time_event_temp != NULL){
+    list_time_event_temp = event_time_list;
+    while(list_time_event_temp){
 	evt = list_time_event_temp->data;
-	fprintf(stderr,"Time: %s,Event: %i\n",ctime(&evt->time),evt->type_event);
+	fprintf(stderr,"Event %i Time: %s", evt->type_event, ctime(&evt->time));
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
 }
+#endif
 
 void timer(void){
-    g_timeout_add(60000,
-		    (GtkFunction)timer_handler,
-		    app->main_window); /* One per minute */
+    app->timer = g_timeout_add(60000,
+			       (GtkFunction)timer_handler,
+			       app->main_window); /* One per minute */
 }
 
 /* Free memory allocated for time event */
 void free_list_time_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
-
+    
     if(!event_time_list)
 	return;
     list_time_event_temp = event_time_list; 
@@ -117,18 +131,19 @@ static gint compare_time(gconstpointer a, gconstpointer b){
 }
 
 /* Add time event  to list */	  
-void time_event_add(time_t time_value,short int type_event){
+void time_event_add(time_t time_value, short type_event){
     struct event_time *evt;
+
     evt = g_new0(struct event_time, 1);
     evt->time = time_value;	  
-    evt->type_event = type_event;	  
+    evt->type_event = type_event;
     event_time_list = g_slist_insert_sorted(event_time_list,evt,compare_time);
 }
 
 /* Add periodic time event  to list */	  
-void add_periodic_event(void){
+void add_periodic_event(time_t last_update){
     if(app->update_interval > 0)
-	time_event_add(time(NULL)+ app->update_interval * 60, AUTOUPDATE);
+	time_event_add(last_update + app->update_interval * 60, AUTOUPDATE);
 }
 
 /* Remove periodic time event  from list */	  
@@ -141,8 +156,11 @@ void remove_periodic_event(void){
     list_time_event_temp = event_time_list;  
     while(list_time_event_temp != NULL){
 	evt = list_time_event_temp->data;
-	if(evt->type_event == AUTOUPDATE)
-	    event_time_list=g_slist_remove(event_time_list,event_time_list->data);
+	if(evt->type_event == AUTOUPDATE){
+	    event_time_list = g_slist_remove(event_time_list, event_time_list->data);
+	    list_time_event_temp = event_time_list;  
+	    g_free(evt);
+	}
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
 }
