@@ -48,7 +48,7 @@ OMWeatherApp	*app = NULL;
 
 /* Translate  temperature Celsius to Farenhait */
 int c2f(int temp){
-    return (temp * 1.8 ) + 32;
+    return (temp * 1.8f ) + 32;
 }
 
 
@@ -64,97 +64,94 @@ void set_font_size(GtkWidget *widget, char font_size){
     pango_font_description_free(pfd);
 }
 
-static gboolean
-enter_button (GtkWidget        *widget,
-              GdkEventCrossing *event)
-{
-   GtkButton *button;
-   GtkWidget *event_widget;
+static gboolean enter_button(GtkWidget *widget,
+        			GdkEventCrossing *event){
+    GtkButton	*button;
+    GtkWidget	*event_widget;
  
-   button = GTK_BUTTON (widget);
-   event_widget = gtk_get_event_widget ((GdkEvent*) event);
-   button->in_button = FALSE;
-   gtk_button_leave (button);
-   return FALSE;
+    button = GTK_BUTTON(widget);
+    event_widget = gtk_get_event_widget((GdkEvent*) event);
+    button->in_button = FALSE;
+    gtk_button_leave(button);
+    return FALSE;
 }
 
 /* Change station to previos at main display */
 static gboolean change_station_prev(GtkWidget *widget,
                     		    GdkEvent *event,
-                    		    gpointer user_data)
-{
+                    		    gpointer user_data){
 
-  GSList *tmplist = NULL;
-  GSList *tmplist_prev = NULL;
-  struct weather_station *ws;
-  tmplist = stations_view_list;
-  while (tmplist != NULL)
-  {
-   ws = tmplist->data;
-     /* Check active station */ 
-     if ((app->current_station_id != NULL) && strcmp(app->current_station_id, ws->id_station) == 0)
-     {
-     /* Get last station if no previos station */
-      if (tmplist_prev == NULL) 
-          tmplist_prev = g_slist_last(tmplist);
-      /* Get station data */
-      ws = tmplist_prev ->data;
-      if(app->current_station_id != NULL)
-        g_free(app->current_station_id);
-        app->current_station_id = g_strdup(ws->id_station); 
-	/* update current station name */
-        if(app->current_station_name)
-	    g_free(app->current_station_name);
-	ws->name_station && (app->current_station_name = strdup(ws->name_station));
-      weather_frame_update(TRUE);
-      config_save_current_station();
-      break;
-     } 
-   tmplist_prev = tmplist;
-   /* Next station in list */
-   tmplist = g_slist_next(tmplist);
-  }
- return TRUE;
+    GSList			*tmplist = NULL;
+    GSList			*tmplist_prev = NULL;
+    struct weather_station	*ws;
+
+    tmplist = stations_view_list;
+    while(tmplist){
+	ws = tmplist->data;
+	/* Check active station */ 
+	if((app->current_station_id != NULL) &&
+		!strcmp(app->current_station_id, ws->id_station)){
+	    /* Get last station if no previos station */
+	    if(!tmplist_prev) 
+    		tmplist_prev = g_slist_last(tmplist);
+	    /* Get station data */
+	    ws = tmplist_prev->data;
+	    if(app->current_station_id)
+    		g_free(app->current_station_id);
+    	    app->current_station_id = g_strdup(ws->id_station); 
+	    /* update current station name */
+    	    if(app->current_station_name)
+		g_free(app->current_station_name);
+	    ws->name_station && (app->current_station_name = strdup(ws->name_station));
+	    app->previos_days_to_show = app->days_to_show;
+	    weather_frame_update(TRUE);
+	    config_save_current_station();
+	    break;
+	} 
+	tmplist_prev = tmplist;
+	/* Next station in list */
+	tmplist = g_slist_next(tmplist);
+    }
+    return TRUE;
 }
 
 /* Change station to next at main display */
-static gboolean
-change_station_next (GtkWidget *widget,
-                           GdkEvent *event,
-                           gpointer user_data)
-{
+static gboolean change_station_next(GtkWidget *widget,
+                    		    GdkEvent *event,
+                    		    gpointer user_data){
 
-  GSList *tmplist = NULL;
-  struct weather_station *ws;
-  tmplist = stations_view_list;
-  while (tmplist != NULL)
-  {
-   ws = tmplist->data;
-     /* Check active station */ 
-     if ((app->current_station_id != NULL) && strcmp(app->current_station_id, ws->id_station) == 0)
-     {
-      tmplist = g_slist_next(tmplist);
-      /* If no next station, get first */
-      if (!tmplist)
-          tmplist = stations_view_list;
-      /* Get station data */
-      ws = tmplist ->data;
-      if (app->current_station_id != NULL) g_free(app->current_station_id);
-        app->current_station_id = g_strdup(ws->id_station); 
-	/* update current station name */
-        if(app->current_station_name)
-	    g_free(app->current_station_name);
-	ws->name_station && (app->current_station_name = strdup(ws->name_station));
-      weather_frame_update(TRUE);
-      config_save_current_station();
-      break;
-     }
-   /* Next station in list */
-   tmplist = g_slist_next(tmplist);
-  }
- return TRUE;
+    GSList 			*tmplist = NULL;
+    struct weather_station	*ws;
+
+    tmplist = stations_view_list;
+    while(tmplist){
+	ws = tmplist->data;
+	/* Check active station */ 
+	if((app->current_station_id != NULL) &&
+		!strcmp(app->current_station_id, ws->id_station)){
+	    tmplist = g_slist_next(tmplist);
+	    /* If no next station, get first */
+	    if(!tmplist)
+    		tmplist = stations_view_list;
+	    /* Get station data */
+	    ws = tmplist->data;
+	    if(app->current_station_id)
+    		g_free(app->current_station_id);
+	    app->current_station_id = g_strdup(ws->id_station); 
+	    /* update current station name */
+	    if(app->current_station_name)
+		g_free(app->current_station_name);
+	    ws->name_station && (app->current_station_name = strdup(ws->name_station));
+	    app->previos_days_to_show = app->days_to_show;
+	    weather_frame_update(TRUE);
+	    config_save_current_station();
+	    break;
+	}
+	/* Next station in list */
+	tmplist = g_slist_next(tmplist);
+    }
+    return TRUE;
 }
-
 /* Set default value */
 void weather_buttons_init(void){
     int i;
@@ -179,20 +176,21 @@ void station_error_window(void){
 
 /* Fill buttons data */
 void weather_buttons_fill(gboolean check_error){
-    int i, offset = 0, count_day;
-    gchar buffer[2048], buffer_icon[2048];
-    time_t current_day,current_time, last_day = 0;
-    struct tm *tm;
-    gboolean flag_last_day = FALSE, error_station_code = FALSE;
-    GSList *tmplist = NULL;
+    int		i, offset = 0, count_day;
+    gchar	buffer[2048], buffer_icon[2048];
+    time_t	current_day,current_time, last_day = 0;
+    struct tm	*tm;
+    gboolean	flag_last_day = FALSE, error_station_code = FALSE;
+    GSList	*tmplist = NULL;
     struct weather_station *ws = NULL;
-    int temp_hi,temp_hi_now,temp_low;
+    int		temp_hi,temp_hi_now,temp_low;
     char	font_size;
     gint	icon_size;
     gchar	*tmp_station_name;
-    GdkPixbuf	*icon = NULL;
-    GtkWidget	*icon_image;
 
+/* Check main widget */
+    if (!app->top_widget)
+	return;
 /* select image and font size */
     switch(app->icons_size){
 	default:
@@ -210,33 +208,26 @@ void weather_buttons_fill(gboolean check_error){
 	break;
     }
     
-  /* Init weather buttons */
+/* Init weather buttons */
     weather_buttons_init();
     count_day = parse_weather_com_xml();
-    
+
     if(check_error)
 	if(count_day == -2){
 	    count_day = 0;
 	    fprintf(stderr, _("Error in xml file\n"));
 	    error_station_code = TRUE;
 	} /* Error in xml file */
-/* 
-    if(count_day == -1){
-	count_day = 0;
-	fprintf(stderr,"Error on xml file");
-    }
-*/
-  /* get current day */  
+/* get current day */  
     current_time = current_day = time(NULL);
     tm = localtime(&current_day);
     tm->tm_sec = 0; tm->tm_min = 0; tm->tm_hour = 0;
     current_day = mktime(tm);
-  /* free time event list */
+/* free time event list */
     free_list_time_event();
-  /* add periodic update */
-    add_periodic_event();
-
-  /* Search day of saving xml near current day */
+/* add periodic update */
+    add_periodic_event(time(NULL));
+/* Search day of saving xml near current day */
     while( (offset < Max_count_weather_day) &&
 	    (current_day > weather_days[offset].date_time) &&
 	    (offset<count_day) )
@@ -321,38 +312,14 @@ void weather_buttons_fill(gboolean check_error){
 		_("N/A"), _("N/A"), _("N/A"));
 	    sprintf(buffer_icon,"%s48.png",path_large_icon);
      /* Add time event to list for next day after last day in xml file */
-	    if(!flag_last_day){
-		time_event_add(last_day+24*60*60,DAYTIMEEVENT);  /* Add time event  to list */	  
+	    if(!flag_last_day && last_day){
+		time_event_add(last_day + 24 * 60 * 60, DAYTIMEEVENT);  /* Add time event  to list */	  
 		flag_last_day = TRUE;
 	    } 
 	}
      /* Write offset in wetaher data for this button */
 	boxs_offset[i] = offset;
      /* Prepare butons for view */   
-//	buttons[i] = gtk_button_new();
-//	if(app->transparency)
-//	    gtk_button_set_relief(GTK_BUTTON(buttons[i]),GTK_RELIEF_NONE);
-//	gtk_button_set_focus_on_click(GTK_BUTTON(buttons[i]),FALSE);
-
-//	labels[i] = gtk_label_new(NULL);
-//	gtk_label_set_markup(GTK_LABEL(labels[i]),buffer);
-//	gtk_label_set_justify(GTK_LABEL(labels[i]),GTK_JUSTIFY_RIGHT);
-     /* Select size font on desktop and icon size */
-//	set_font_size(labels[i], font_size);
-//	icon = gdk_pixbuf_new_from_file_at_size(buffer_icon,
-//						icon_size,
-//						icon_size, NULL);
-     /* Create box for image and label */
-//	boxs[i] = gtk_hbox_new(FALSE, 0);
-//	icon_image = gtk_image_new_from_pixbuf(icon);
-//	if (icon) g_object_unref (icon);
-     /* Packing buttons to box */
-//	gtk_box_pack_start(GTK_BOX(boxs[i]), icon_image, FALSE, FALSE, 0);
-//	gtk_box_pack_start(GTK_BOX(boxs[i]), labels[i], FALSE, FALSE, 0);
-//	gtk_container_add(GTK_CONTAINER(buttons[i]), boxs[i]);
- /* Connect signal button */
-//	g_signal_connect(buttons[i], "released", G_CALLBACK(weather_window_popup_show), NULL);
-//	g_signal_connect(buttons[i], "enter", G_CALLBACK(enter_button), NULL); 
 	app->buttons[i] = create_weather_day_button(buffer, buffer_icon, icon_size, app->transparency, font_size);
 	g_signal_connect(app->buttons[i]->button, "released", G_CALLBACK(weather_window_popup_show), NULL);
 	g_signal_connect(app->buttons[i]->button, "enter", G_CALLBACK(enter_button), NULL); 
@@ -374,7 +341,6 @@ void weather_buttons_fill(gboolean check_error){
 	    ws->name_station = NULL;
 	tmp_station_name = NULL;
     }
-
 /* create main panel */
     app->main_window = gtk_table_new(2, 1, FALSE);
     create_panel(app->main_window, app->icons_layout, app->transparency, tmp_station_name, font_size);
@@ -388,7 +354,8 @@ void weather_buttons_fill(gboolean check_error){
 void weather_frame_update(gboolean check){
     
     free_memory(FALSE);
-    gtk_widget_destroy(app->main_window);
+    if (app->main_window)
+        gtk_widget_destroy(app->main_window);
     if(check) 
 	weather_buttons_fill(TRUE);
     else
@@ -397,7 +364,8 @@ void weather_frame_update(gboolean check){
 
 /* Get Weather xml file from weather.com */
 void update_weather(void){
-    flag_update = g_timeout_add(100, (GSourceFunc)download_html, NULL);
+    if (app->flag_updating == 0)
+	app->flag_updating = g_timeout_add(100, (GSourceFunc)download_html, NULL);
 }
 
 
@@ -411,17 +379,20 @@ void* hildon_home_applet_lib_initialize(void *state_data,
         g_debug(_("Error initializing the OMWeather applet"));
         return NULL;
     }
-    fprintf(stderr, "\nOMWeather applet initialize %p %d\n",
-		    state_data, *state_size);
+    #ifdef PC_EMULATOR
+	fprintf(stderr, "\nOMWeather applet initialize %p %d\n",
+			state_data, *state_size);
+    #endif
     app = g_new0(OMWeatherApp, 1);
     memset(app, 0, sizeof(OMWeatherApp));
     app->osso = osso;
+    app->flag_updating = 0;
 /* create i18n hash for values coming from xml file */
     app->hash = hash_table_create();
     app->icons_size = LARGE;
     app->icons_layout = ONE_ROW;
     app->transparency = TRUE;
-    app->days_to_show = 5;
+    app->days_to_show = app->previos_days_to_show = 5;
     app->distance_units = KILOMETERS;
     app->wind_units = METERS_S;
     app->temperature_units = CELSIUS;
@@ -443,7 +414,9 @@ void* hildon_home_applet_lib_initialize(void *state_data,
 int hildon_home_applet_lib_save_state(void *raw_data,
 				    void **state_data, 
 				    int *state_size){
-    fprintf(stderr, "\nOMWeather applet save state\n");
+    #ifdef PC_EMULATOR
+	fprintf(stderr, "\nOMWeather applet save state\n");
+    #endif
     (*state_data) = NULL;
     if(state_size)
 	(*state_size) = 0;
@@ -451,21 +424,38 @@ int hildon_home_applet_lib_save_state(void *raw_data,
 }
 
 void hildon_home_applet_lib_background(void *raw_data){
-    fprintf(stderr, "\nOMWeather applet background\n");
+    #ifdef PC_EMULATOR
+        fprintf(stderr, "\nOMWeather applet background\n");
+    #endif
 }
 
 void hildon_home_applet_lib_foreground(void *raw_data){
-    fprintf(stderr, "\nOMWeather applet foreground\n");
+    #ifdef PC_EMULATOR
+	fprintf(stderr, "\nOMWeather applet foreground\n");
+    #endif
 }
 
 void hildon_home_applet_lib_deinitialize(void *applet_data){
     osso_context_t *osso;
+    gboolean check;
+    
+    #ifdef PC_EMULATOR
+	fprintf(stderr, "\nOMWeather applet deinitialize\n");
+    #endif
+    /* It is switch off the timer */	
+    check = g_source_remove(app->timer);
+    /* If downloading then switch off it */
+    if (app->flag_updating != 0){
+	check = g_source_remove(app->flag_updating);
+	clean_download();
+    }
 
-    fprintf(stderr, "\nOMWeather applet deinitialize\n");
     config_save(); /* Not work!!!! Only 770. Why? I am not understand why this place not run when close applet 
-			On n800 this work*/
-    osso  = (osso_context_t*)applet_data;
+			On n800 this work */
+			
+    osso = (osso_context_t*)applet_data;
     if(app){
+	app->top_widget = NULL;    
 	free_memory(TRUE);
 	g_free(app);
     }
@@ -475,7 +465,9 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
 
 GtkWidget* hildon_home_applet_lib_settings(void *applet_data,
 					    GtkWindow *parent){
-    fprintf(stderr, "\nOMWeather applet settings\n");
+    #ifdef PC_EMULATOR
+	fprintf(stderr, "\nOMWeather applet settings\n");
+    #endif
     return NULL;
 }
 /* create days panel and station name panel */
@@ -553,9 +545,9 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
     gtk_button_set_focus_on_click(GTK_BUTTON(next_station_name_btn), FALSE);
     gtk_button_set_focus_on_click(GTK_BUTTON(station_name_btn), FALSE); 
 /* attach buttons to header panel */
-    gtk_table_attach( (GtkTable*)header_panel, previos_station_name_btn, 0, 1, 0, 1 ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
-    gtk_table_attach( (GtkTable*)header_panel, station_name_btn, 1, 2, 0, 1  ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0); 
-    gtk_table_attach( (GtkTable*)header_panel, next_station_name_btn, 2, 3, 0, 1  ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
+    gtk_table_attach( (GtkTable*)header_panel, previos_station_name_btn, 0, 1, 0, 1 , GTK_EXPAND, GTK_EXPAND, 0, 0);
+    gtk_table_attach( (GtkTable*)header_panel, station_name_btn, 1, 2, 0, 1  , GTK_EXPAND, GTK_EXPAND, 0, 0); 
+    gtk_table_attach( (GtkTable*)header_panel, next_station_name_btn, 2, 3, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
 /* create days panel */
     switch(layout){
 	default:
@@ -577,11 +569,9 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
 	switch(layout){
 	    default:
 	    case ONE_ROW:
-//		gtk_table_attach( (GtkTable*)days_panel, buttons[n], n, n + 1, 0, 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0 );
 		gtk_table_attach( (GtkTable*)days_panel, app->buttons[n]->button, n, n + 1, 0, 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0 );
 	    break;
 	    case ONE_COLUMN:
-//		gtk_table_attach( (GtkTable*)days_panel, buttons[n], 0, 1, n, n + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		gtk_table_attach( (GtkTable*)days_panel, app->buttons[n]->button, 0, 1, n, n + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 	    break;
 	    case TWO_ROWS:
@@ -589,10 +579,8 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
 		    x = 0; y = 1;
 		}
 		if(!y)
-//		    gtk_table_attach( (GtkTable*)days_panel, buttons[n], x, x + 1, 0, 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		    gtk_table_attach( (GtkTable*)days_panel, app->buttons[n]->button, x, x + 1, 0, 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		else
-//		    gtk_table_attach( (GtkTable*)days_panel, buttons[n], x, x + 1, 1, 2,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		    gtk_table_attach( (GtkTable*)days_panel, app->buttons[n]->button, x, x + 1, 1, 2,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 	    break;
 	    case TWO_COLUMNS:
@@ -600,10 +588,8 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
 		    x = 0; y = 1;
 		}
 		if(!y)
-//		    gtk_table_attach( (GtkTable*)days_panel, buttons[n], 0, 1, x, x + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		    gtk_table_attach( (GtkTable*)days_panel, app->buttons[n]->button, 0, 1, x, x + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		else
-//		    gtk_table_attach( (GtkTable*)days_panel, buttons[n], 1, 2, x, x + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		    gtk_table_attach( (GtkTable*)days_panel, app->buttons[n]->button, 1, 2, x, x + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 	    break;
 	}
@@ -620,64 +606,95 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
     g_signal_connect(station_name_btn, "enter", G_CALLBACK (enter_button), NULL); 
     gtk_container_set_focus_child(GTK_CONTAINER(panel), station_name_btn); 
     if(station_name_btn)
-	g_object_unref (station_name_btn);
+	g_object_unref(station_name_btn);
 }
 
 /* free used memory from OMWeather struct */
 void free_memory(gboolean flag){
-    int i;
+    int    i;
+    GSList *tmplist = NULL;
+    struct weather_station *ws;
     
-    if(app->weather_dir_name && flag){
-	g_free(app->weather_dir_name);
-	app->weather_dir_name = NULL;
+    if(flag){
+	if(app->weather_dir_name){
+	    g_free(app->weather_dir_name);
+	    app->weather_dir_name = NULL;
+	}
+	if(app->icon_set){
+	    g_free(app->icon_set);
+	    app->icon_set = NULL;
+	}
+	if(app->current_country){
+	    g_free(app->current_country);
+	    app->current_country = NULL;
+	}	
+	if(app->current_station_name){
+	    g_free(app->current_station_name);
+	    app->current_station_name = NULL;
+	}
+        if(app->current_station_id){
+	    g_free(app->current_station_id);
+	    app->current_station_id = NULL;
+	}
+	if(app->iap_http_proxy_host){
+	    g_free(app->iap_http_proxy_host);
+	    app->iap_http_proxy_host = NULL;
+	}
+	if(app->hash){
+	    g_hash_table_destroy(app->hash);
+	    app->hash = NULL;
+	}
+	/* clean stations_view_list */
+	if(stations_view_list){
+	    if(g_slist_length(stations_view_list) > 0){
+		tmplist = stations_view_list;
+    		while(tmplist){
+    		    ws = tmplist->data;
+		    g_free(ws->id_station);
+		    g_free(ws->name_station);
+		    g_free(ws);
+		    tmplist = g_slist_next(tmplist);
+		}
+	    }	    
+	    g_slist_free(stations_view_list);
+	    stations_view_list = NULL;
+	}
     }
-    if(app->icon_set && flag){
-	g_free(app->icon_set);
-	app->icon_set = NULL;
-    }
-    if(app->current_country && flag){
-	g_free(app->current_country);
-	app->current_country = NULL;
-    }
-    if(app->current_station_name && flag){
-	g_free(app->current_station_name);
-	app->current_station_name = NULL;
-    }
-    if(app->current_station_id && flag){
-	g_free(app->current_station_id);
-	app->current_station_id = NULL;
-    }
-
-    if(app->iap_http_proxy_host && flag){
-	g_free(app->iap_http_proxy_host);
-	app->iap_http_proxy_host = NULL;
-    }
-    if(app->hash && flag){
-	g_hash_table_destroy(app->hash);
-	app->hash = NULL;
-    }
-    if(stations_view_list && flag){
-	g_slist_free(stations_view_list);
-	stations_view_list = NULL;
-    }
-    for(i = 0; i < app->days_to_show; i++)
-	delete_weather_day_button( &(app->buttons[i]) );
+    
+    if(app->top_widget){
+#ifdef PC_EMULATOR
+	fprintf(stderr, "\nDays current %d\n", app->days_to_show);
+	fprintf(stderr, "\nDays previos %d\n", app->previos_days_to_show);
+#endif
+	for(i = 0; i < app->previos_days_to_show; i++)
+	    delete_weather_day_button(FALSE, &(app->buttons[i]) );    
+	if(app->main_window){
+	    gtk_widget_destroy(app->main_window);
+	    app->main_window = NULL;
+	}	
+    }	    
+    else
+	for(i = 0; i < app->days_to_show; i++)
+	    delete_weather_day_button( TRUE, &(app->buttons[i]) );
 }
 
 WDB* create_weather_day_button(const char *text, const char *icon, const int icon_size, gboolean transparency, char font_size){
+
     WDB	*new_day_button;
     
-    new_day_button = g_new(WDB, 1);
+    new_day_button = g_new0(WDB, 1);
     if(!new_day_button)
 	return NULL;
     /* create day icon buffer */
-    new_day_button->icon_buffer = gdk_pixbuf_new_from_file_at_size(icon,
-								    icon_size,
-								    icon_size, NULL);
+    new_day_button->icon_buffer
+	    = gdk_pixbuf_new_from_file_at_size(icon,
+						icon_size,
+						icon_size, NULL);
     if(!new_day_button->icon_buffer)
 	return NULL;
     /* create day icon image from buffer */
     new_day_button->icon_image = gtk_image_new_from_pixbuf(new_day_button->icon_buffer);
+    g_object_unref(G_OBJECT(new_day_button->icon_buffer));
     /* create day button */
     new_day_button->button = gtk_button_new();
     if(transparency)
@@ -698,20 +715,34 @@ WDB* create_weather_day_button(const char *text, const char *icon, const int ico
     return new_day_button;
 }
 
-void delete_weather_day_button(WDB **day){
+void delete_weather_day_button(gboolean after_all_destroy,WDB **day){
 
-    if(*day){
-	if( (*day)->icon_image )
-	    gtk_widget_destroy( (*day)->icon_image );
-	if( (*day)->icon_buffer )
-	     g_object_unref( (*day)->icon_buffer );
-	if( (*day)->label )
-	    gtk_widget_destroy( (*day)->label );
-	if( (*day)->box )
-	    gtk_widget_destroy( (*day)->box );
-	if( (*day)->button )
-	    gtk_widget_destroy( (*day)->button );
-	g_free(*day);
-	*day = NULL;
+    if(after_all_destroy){
+	if(*day){
+	    g_free(*day);
+	    *day = NULL;
+	}
+    }
+    else{
+	if(*day){
+	    if( (*day)->icon_image ){
+		gtk_widget_destroy( (*day)->icon_image );
+		(*day)->icon_image = NULL;
+	    }
+	    if( (*day)->label ){
+		gtk_widget_destroy( (*day)->label );    
+		(*day)->label = NULL;
+	    }    
+	    if( (*day)->box ){
+		gtk_widget_destroy( (*day)->box );
+		(*day)->box = NULL;
+	    }    
+	    if( (*day)->button ){
+		gtk_widget_destroy( (*day)->button );
+		(*day)->button = NULL;
+	    }    
+	    g_free(*day);
+	    *day = NULL;
+	}
     }
 }
