@@ -226,15 +226,19 @@ gboolean download_html(gpointer data){
     }
     
     /* If not connected and it autoupdate do go away */
-    if (!app->show_update_window && !app->iap_connected)
+    if (!app->show_update_window && !app->iap_connected){
+    	app->flag_updating = 0;
 	return FALSE;
-
+    }
     if (app->iap_connected) 
 	second_attempt = TRUE;
     if( app->show_update_window && (!second_attempt) ){
 	/* Check this code */
-        if(osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK)
+        if(osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK){
+	    app->flag_updating = 0;
     	    return FALSE;
+	}   
+	app->flag_updating = 0; 
         return FALSE;
     }
     
@@ -258,7 +262,8 @@ gboolean download_html(gpointer data){
 	    if(full_filename_new_xml){
 	        g_string_free(full_filename_new_xml, TRUE);    
 	    	full_filename_new_xml = NULL;
-	    }	 
+	    }
+	    app->flag_updating = 0;	 
 	    return FALSE; /* The strange error */		
 	}    
 	/* Init easy_curl */
@@ -279,6 +284,7 @@ gboolean download_html(gpointer data){
 	/* set options for the curl easy handle */
         curl_easy_setopt(curl_handle, CURLOPT_WRITEDATA, &html_file);		
         curl_easy_setopt(curl_handle, CURLOPT_WRITEFUNCTION, data_read);	
+	
         /* for debug */
         /*    curl_easy_setopt(curl_handle, CURLOPT_URL, "http://127.0.0.1"); */
         /* add the easy handle to a multi session */
@@ -302,6 +308,7 @@ gboolean download_html(gpointer data){
 			fprintf(stderr," Error remove handle %p\n",curl_handle);
 			
 		    curl_easy_cleanup(curl_handle); 
+		    curl_handle = NULL;
 
 		    if(html_file.stream)
         		fclose(html_file.stream);
@@ -337,7 +344,10 @@ gboolean download_html(gpointer data){
 		    msg->easy_handle = NULL;
 		}
 		*/
-/*		curl_easy_cleanup(curl_handle); */
+		if (curl_handle){
+		    curl_easy_cleanup(curl_handle); 
+		    curl_handle = NULL;
+		}
 		curl_multi_cleanup(curl_multi);
 		curl_multi = NULL;
 		curl_handle = NULL;
@@ -348,11 +358,25 @@ gboolean download_html(gpointer data){
 		if(full_filename_new_xml){
 		    g_string_free(full_filename_new_xml, TRUE);    	  
 		    full_filename_new_xml = NULL;
-		}     
+		}
+		app->flag_updating = 0;     
 		return FALSE; /* This is the end */
 	    }
 	}
 	return TRUE;
     }
+    app->flag_updating = 0;
     return FALSE;
 }
+
+void clean_download (){
+    if (curl_multi)
+	curl_multi_cleanup(curl_multi);
+    curl_multi = NULL;
+    curl_handle = NULL;
+    if(update_window){
+        gtk_widget_destroy(update_window);
+        update_window = NULL;
+    }
+
+}
