@@ -156,25 +156,26 @@ void changed_country(void){
 
 /* Select item on state combobox */
 void changed_state(void){
-    GtkTreeModel *model;
-    GSList *current;
-    char flag; /* Flag for country processing */
-    char flag_necessary_state; /* Flag for finding country or province or state */
-    char out_buffer[1024]; /* buffer for work with stations.txt files */
-    static gchar *gstate_name = NULL;
-    FILE *stations_file; 
-    char state_name[21];
-    char temp_station_name[21];
-    char temp_station_code[9];
+    GtkTreeModel	*model = NULL;
+    GSList		*current = NULL;
+    char		flag,			/* Flag for country processing */
+			flag_necessary_state,	/* Flag for finding country or province or state */
+			out_buffer[1024],	/* buffer for work with stations.txt files */
+			state_name[21],
+			temp_station_name[21],
+			temp_station_code[9];
+    static gchar	*gstate_name = NULL;
+    FILE		*stations_file = NULL; 
     struct station_and_weather_code *sc;
-    int count_station = 0; /* Count station of state or region */
-    int i;
-  
+    int			count_station = 0,	/* Count station of state or region */
+			i;
 /* Search Country in the ComboBox*/
     flag = FALSE;    
 /* Clear the list. */
     model = gtk_combo_box_get_model(GTK_COMBO_BOX(stations));
     gtk_list_store_clear(GTK_LIST_STORE(model));
+    free_list_stations();
+    
     gstate_name = gtk_combo_box_get_active_text(GTK_COMBO_BOX(states));
     /* Search state or province on country and add stations to combobox*/
     if((stations_file = fopen(STATIONS_FILE,"r")) != NULL){
@@ -213,8 +214,8 @@ void changed_state(void){
 	  /* Add station and station code to list */	  
 		    sc = g_new0(struct station_and_weather_code, 1);
 		    sc->station_name = g_strdup(temp_station_name);	  
-		    sc->station_code = g_strdup(temp_station_code);	  
-		    stations_list_in_state = g_slist_append(stations_list_in_state, sc); /* Necessary free list  beyond !!! */	  
+		    sc->station_code = g_strdup(temp_station_code);
+		    stations_list_in_state = g_slist_append(stations_list_in_state, sc); /* Necessary free list  beyond !!! */
 		}    	  
 	    }
 	}
@@ -244,6 +245,7 @@ void changed_stations(void){
 	    if(_weather_station_id_temp)
 		g_free(_weather_station_id_temp);
 	    _weather_station_id_temp = g_strdup(sc->station_code);
+	    g_free(temp_string);
 	    break;    
 	}
 	g_free(temp_string);
@@ -375,6 +377,9 @@ static gboolean weather_delete_station(GtkWidget *widget,
 	  (ws->name_station == NULL && station_selected == NULL)){
       /* Remove station from the Station List */
 	    stations_view_list = g_slist_remove(stations_view_list, ws);
+	    g_free(ws->id_station);
+	    g_free(ws->name_station);
+	    g_free(ws);
 	    gtk_list_store_clear(station_list_store);
 	    tmplist = stations_view_list;
 
@@ -673,16 +678,16 @@ void weather_window_preference(GtkWidget *widget,
 				GdkEvent *event,
 				gpointer user_data){
 
-    GtkWidget	*window_config,
-		*notebook,
-		*label,
-		*table,
-		*font_color,
-		*chk_transparency,
-		*scrolled_window,
-		*button_add,
-		*button_del,
-		*button_ren;		
+    GtkWidget	*window_config = NULL,
+		*notebook = NULL,
+		*label = NULL,
+		*table = NULL,
+		*font_color = NULL,
+		*chk_transparency = NULL,
+		*scrolled_window = NULL,
+		*button_add = NULL,
+		*button_del = NULL,
+		*button_ren = NULL;		
 
     char flag_update_icon = '\0'; /* Flag update main weather icon of desktop */
     gboolean flag_tuning_warning; /* Flag for show the warnings about tuning images of applet */
@@ -691,6 +696,7 @@ void weather_window_preference(GtkWidget *widget,
     static GSList *time_update_list_temp = NULL; /* Temporary list for time update */
     struct time_update *tu; /* Temporary for time update list */
     static char *temp_string; /* Temporary for the results differnet strdup functions */
+    static int result_gtk_dialog_run; /* Temporary for the gtk_dialog_run result */
    
     not_event = TRUE;
     flag_update_station = FALSE;
@@ -858,6 +864,7 @@ void weather_window_preference(GtkWidget *widget,
     font_color = gtk_color_button_new();
     gtk_container_add(GTK_CONTAINER(label), font_color);
     gtk_color_button_set_color(GTK_COLOR_BUTTON(font_color), &(app->font_color));
+    gtk_widget_show(font_color);
     /* Transparency */
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_label_new(_("Transparency")),
@@ -959,8 +966,9 @@ void weather_window_preference(GtkWidget *widget,
 	app->popup_window = NULL;
     }
 
+    while (0 != (result_gtk_dialog_run = gtk_dialog_run(GTK_DIALOG(window_config)))){
 /* start dialog window */
-    switch(gtk_dialog_run(GTK_DIALOG(window_config))){
+      switch(result_gtk_dialog_run){
 	case GTK_RESPONSE_ACCEPT:/* Pressed Button Ok */
 /* icon set */	
 	    temp_string = gtk_combo_box_get_active_text(GTK_COMBO_BOX(iconset));
@@ -995,6 +1003,7 @@ void weather_window_preference(GtkWidget *widget,
 	    }
 /* Days to show */
 	    if( gtk_combo_box_get_active((GtkComboBox*)days_number)!= app->days_to_show - 1){
+		app->previos_days_to_show = app->days_to_show;/* store previos number of icons */
 		app->days_to_show = gtk_combo_box_get_active((GtkComboBox*)days_number);
 		app->days_to_show++;
     		flag_update_icon = TRUE;
@@ -1029,22 +1038,22 @@ void weather_window_preference(GtkWidget *widget,
 		temp_string =gtk_combo_box_get_active_text(GTK_COMBO_BOX(update_time));
 		if(!strcmp(tu->name_between_time,temp_string)){
 		    app->update_interval = tu->between_time;
-		    if(app->update_interval)
-			add_periodic_event();
-		    else
-			remove_periodic_event();
+		    remove_periodic_event();
+		    add_periodic_event(time(NULL));
+		    g_free(temp_string);
 		    break;
 		}    	  
 		g_free(temp_string);
     		time_update_list_temp = g_slist_next(time_update_list_temp);
     	    }
     	    config_save();
-	    if(flag_update_icon)
+	    if(flag_update_icon){
     		weather_frame_update(FALSE);
+		app->previos_days_to_show = app->days_to_show;/* store previos number of icons */
+	    }	
 	    if(flag_update_station){
-		if (app->iap_connected){
-		    if( g_slist_length(stations_view_list) > 0 )
-		    {
+		if(app->iap_connected){
+		    if( g_slist_length(stations_view_list) > 0 ){
 			app->show_update_window = TRUE;
 			update_weather();
 		    }
@@ -1059,8 +1068,7 @@ void weather_window_preference(GtkWidget *widget,
 	break;
 	default:/* Pressed CANCEL */
 	    if( flag_update_station && app->iap_connected ){
-		if( g_slist_length(stations_view_list) > 0 )
-		{
+		if( g_slist_length(stations_view_list) > 0 ){
 		    app->show_update_window = TRUE;
 		    update_weather();
 		}
@@ -1068,9 +1076,12 @@ void weather_window_preference(GtkWidget *widget,
 /* ???		config_save(); */
 	    }
 	break;
+      }
+     if  (result_gtk_dialog_run !=  GTK_RESPONSE_HELP) 
+        break; /* We  leave a cycle WHILE */
     }
     not_event = FALSE;
-    if (flag_tuning_warning)
+    if(flag_tuning_warning)
 	hildon_banner_show_information(app->main_window,
 					NULL,
 					_("Use Edit layout \nfor tuning images of applet"));
@@ -1114,7 +1125,8 @@ void create_help_dialog(void){
 		*notebook,
 		*title;
     char	tmp_buff[2048];
-		    
+    gint	result;
+
     help_dialog = gtk_dialog_new_with_buttons(_("Other Maemo Weather Info"),
         				NULL,
 					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -1162,7 +1174,7 @@ void create_help_dialog(void){
         			title = gtk_label_new(_("Thanks")));
     gtk_widget_show_all(help_dialog);
 /* start dialog window */
-    gtk_dialog_run(GTK_DIALOG(help_dialog));
+    result = gtk_dialog_run(GTK_DIALOG(help_dialog));
     gtk_widget_destroy(help_dialog);
 }
 
