@@ -33,22 +33,15 @@
 
 #include "weather-home_common.h"
 
-extern gchar     *_weather_state_name;
-extern gchar     *_weather_station_name;
-extern gchar     *_weather_station_id;
-extern gchar     *_weather_dir_name;
-extern GtkWidget *buttons[];
-extern int 	 boxs_offset[];
-extern GtkWidget *weather_window_popup;
-extern GtkWidget *box;
-extern gchar     path_large_icon[];
-extern gchar      _weather_temperature_unit;
-extern	gint	days_to_show;
-extern	gint	distance_units;
+extern	GtkWidget	*buttons[];
+extern	int		boxs_offset[];
+extern	gchar		path_large_icon[];
 
-gboolean weather_window_popup_show (GtkWidget *widget,GdkEvent *event,gpointer user_data);
+void weather_window_popup_show(GtkWidget *widget,GdkEvent *event,gpointer user_data);
 void weather_window_preference (GtkWidget *widget,GdkEvent *event,gpointer user_data);
 int c2f(int temp);
 void set_font_size(GtkWidget *widget, char font_size);
+int convert_wind_units(int to, int value);
+extern gpointer hash_table_find(gpointer key);
 
 #endif
